@@ -21,12 +21,12 @@ from scipy import signal
 
 # Below are functions to compute FFTs and inverse FFTs, including the special cases
 # of purely real input, at greater-than-double precision.  The data type used is
-# Python's numpy.float128, and precision depends on your machine's platform.  Check
-# the resolution using numpy.finfo(numpy.float128).
+# Python's numpy.longdouble, and precision depends on your machine's platform.  Check
+# the resolution using numpy.finfo(numpy.longdouble).
 
 # Compute pi and 2*pi to long double precision.
-pi = np.floor(np.float128(np.pi * 1e14)) / 1e14 + 3.2384626433832795e-15
-two_pi = np.floor(np.float128(np.pi * 2e14)) / 1e14 + 6.476925286766559e-15
+pi = np.floor(np.longdouble(np.pi * 1e14)) / 1e14 + 3.2384626433832795e-15
+two_pi = np.floor(np.longdouble(np.pi * 2e14)) / 1e14 + 6.476925286766559e-15
 
 
 def find_prime_factors(N):
@@ -111,7 +111,7 @@ def find_exp_array(N, inverse=False):
     exp_array : array-like
     """
     N = int(N)
-    exp_array = np.zeros(N, dtype=np.complex256)
+    exp_array = np.zeros(N, dtype=np.clongdouble)
 
     # If this is the inverse DFT, just don't negate 2*pi
     if inverse:
@@ -203,10 +203,10 @@ def dft(td_data, exp_array=None, return_double=False, inverse=False):
         # the code do it once.
         exp_array = find_exp_array(N, inverse=inverse)
 
-    fd_data = np.zeros(N, dtype=np.complex256)
+    fd_data = np.zeros(N, dtype=np.clongdouble)
 
     # The first term is the DC component, which is just the sum.
-    fd_data[0] = sum(np.complex256(td_data))
+    fd_data[0] = sum(np.clongdouble(td_data))
 
     # Since this function is most often called by fft(), N is most likely a prime, so assume
     # there are no more trivial multiplications
@@ -251,12 +251,12 @@ def rdft(td_data, exp_array=None, return_double=False, return_full=False):
         exp_array = find_exp_array(N)
 
     if return_full:
-        fd_data = np.zeros(N, dtype=np.complex256)
+        fd_data = np.zeros(N, dtype=np.clongdouble)
     else:
-        fd_data = np.zeros(N_out, dtype=np.complex256)
+        fd_data = np.zeros(N_out, dtype=np.clongdouble)
 
     # The first term is the DC component, which is just the sum.
-    fd_data[0] = sum(np.complex256(td_data))
+    fd_data[0] = sum(np.clongdouble(td_data))
 
     # Since this function is most often called by fft(), N is most likely a prime,
     # so assume there are no more trivial multiplications
@@ -315,11 +315,11 @@ def irdft(fd_data, exp_array=None, return_double=False, N=None, normalize=True):
         # the code do it once.
         exp_array = find_exp_array(N, inverse=True)
 
-    td_data = np.zeros(N, dtype=np.float128)
+    td_data = np.zeros(N, dtype=np.longdouble)
 
     # The first term is the DC component, which is just the sum.
-    td_data[0] = (sum(np.float128(np.real(fd_data)))
-                  + sum(np.float128(np.real(fd_data)[1: 1 + N - N_in])))
+    td_data[0] = (sum(np.longdouble(np.real(fd_data)))
+                  + sum(np.longdouble(np.real(fd_data)[1: 1 + N - N_in])))
 
     # Since this function is most often called by irfft(), N is most likely a prime, so assume
     # there are no more trivial multiplications
@@ -374,7 +374,7 @@ def fft(td_data, prime_factors=None, exp_array=None, return_double=False,
         if return_double:
             return np.complex128(td_data)
         else:
-            return np.complex256(td_data)
+            return np.clongdouble(td_data)
 
     if prime_factors is None:
         # Find prime factors
@@ -406,7 +406,7 @@ def fft(td_data, prime_factors=None, exp_array=None, return_double=False,
         return dft(td_data, exp_array=exp_array, return_double=return_double)
     else:
         # We will break this up into smaller Fourier transforms
-        fd_data = np.zeros(N, dtype=np.complex256)
+        fd_data = np.zeros(N, dtype=np.clongdouble)
         num_ffts = prime_factors[0]
         N_mini = N // num_ffts
         for i in range(num_ffts):
@@ -536,9 +536,9 @@ def prime_fft(td_data, return_double=False, inverse=False, exp_array2=None, M=No
         M, prime_factors = find_M(2 * N - 1)
     if exp_array is None:
         exp_array = find_exp_array(M)
-    A_n = np.concatenate((td_data * exp_array2, np.zeros(M - N, dtype=np.complex256)))
+    A_n = np.concatenate((td_data * exp_array2, np.zeros(M - N, dtype=np.clongdouble)))
     b_n = np.conj(exp_array2)
-    B_n = np.concatenate((b_n, np.zeros(M - 2 * N + 1, dtype=np.complex256), b_n[1:][::-1]))
+    B_n = np.concatenate((b_n, np.zeros(M - 2 * N + 1, dtype=np.clongdouble), b_n[1:][::-1]))
 
     # Do the convolution using the convolution theorem and the Cooley-Tukey algorithm, and
     # multiply by exp_array2.
@@ -599,9 +599,9 @@ def prime_irfft(fd_data, return_double=False, N=None, normalize=True, exp_array2
         exp_array = find_exp_array(M)
     A_n = np.concatenate((fd_data * exp_array2[:N_in],
                           np.conj(fd_data[1:N-N_in+1][::-1]) * exp_array2[N_in:],
-                          np.zeros(M - N, dtype=np.complex256)))
+                          np.zeros(M - N, dtype=np.clongdouble)))
     b_n = np.conj(exp_array2)
-    B_n = np.concatenate((b_n, np.zeros(M - 2 * N + 1, dtype=np.complex256), b_n[1:][::-1]))
+    B_n = np.concatenate((b_n, np.zeros(M - 2 * N + 1, dtype=np.clongdouble), b_n[1:][::-1]))
 
     # Do the convolution using the convolution theorem and the Cooley-Tukey algorithm, and
     # multiply by exp_array2.
@@ -659,10 +659,10 @@ def prime_rfft(td_data, return_double=False, return_full=False, exp_array2=None,
     if exp_array is None:
         exp_array = find_exp_array(M)
     A_n = np.concatenate((td_data * exp_array2,
-                          np.zeros(M - N, dtype=np.complex256)))
+                          np.zeros(M - N, dtype=np.clongdouble)))
     b_n = np.conj(exp_array2)
     B_n = np.concatenate((b_n[:N_out],
-                          np.zeros(M - N - N_out + 1, dtype=np.complex256),
+                          np.zeros(M - N - N_out + 1, dtype=np.clongdouble),
                           b_n[1:][::-1]))
 
     # Do the convolution using the convolution theorem and the Cooley-Tukey algorithm, and
@@ -715,7 +715,7 @@ def rfft(td_data, prime_factors=None, exp_array=None, return_double=False,
         if return_double:
             return np.complex128(td_data)
         else:
-            return np.complex256(td_data)
+            return np.clongdouble(td_data)
 
     if prime_factors is None:
         # Find prime factors
@@ -751,7 +751,7 @@ def rfft(td_data, prime_factors=None, exp_array=None, return_double=False,
     else:
         # We will break this up into smaller Fourier transforms.
         # Therefore, we still need to allocate enough memory for N elements.
-        fd_data = np.zeros(N, dtype=np.complex256)
+        fd_data = np.zeros(N, dtype=np.clongdouble)
         num_ffts = prime_factors[0]
         N_mini = N // num_ffts
         N_mini_out = N_mini // 2 + 1
@@ -866,7 +866,7 @@ def irfft(fd_data, prime_factors=None, exp_array=None, return_double=False,
         if return_double:
             return np.float64(fd_data)
         else:
-            return np.float128(fd_data)
+            return np.longdouble(fd_data)
 
     if prime_factors is None:
         # First, find N, the original number of samples. If the imaginary part of the last
@@ -924,7 +924,7 @@ def irfft(fd_data, prime_factors=None, exp_array=None, return_double=False,
                      N=N, normalize=normalize)
     else:
         # We will break this up into smaller Fourier transforms
-        td_data = np.zeros(N, dtype=np.float128)
+        td_data = np.zeros(N, dtype=np.longdouble)
         num_ffts = prime_factors[0]
         N_mini = N // num_ffts
         td_data[:N_mini] = irfft(fd_data[0::num_ffts], prime_factors=prime_factors[1:],
@@ -938,7 +938,7 @@ def irfft(fd_data, prime_factors=None, exp_array=None, return_double=False,
                                  M_irfft_exp_array=M_irfft_exp_array)
 
         # The rest of the transforms will, in general, produce complex output
-        td_data_complex = np.zeros(N - N_mini, dtype=np.complex256)
+        td_data_complex = np.zeros(N - N_mini, dtype=np.clongdouble)
         for i in range(1, num_ffts):
             td_data_complex[(i - 1)
                             * N_mini: i
@@ -1072,7 +1072,7 @@ def DPSS(N, alpha, return_double=False, max_time=10):
 
     # Now do this with extra precision
     omega_c_Ts = two_pi * alpha / N
-    sinc = np.zeros(N, dtype=np.float128)
+    sinc = np.zeros(N, dtype=np.longdouble)
     sinc[0] = omega_c_Ts
     for i in range(1, N):
         sinc[i] = np.sin(omega_c_Ts * i) / i
@@ -1094,12 +1094,12 @@ def DPSS(N, alpha, return_double=False, max_time=10):
     return np.concatenate((dpss, dpss[::-1][N % 2:]))
 
 
-factorials_inv = np.zeros(1755, dtype=np.float128)
+factorials_inv = np.zeros(1755, dtype=np.longdouble)
 factorials_inv[0] = 1.0
 current = 1
 for n in range(1, 1755):
     current *= n
-    factorials_inv[n] = 1.0 / np.float128(str(current))
+    factorials_inv[n] = 1.0 / np.longdouble(str(current))
 
 
 # Dolph-Chebyshev window
@@ -1143,7 +1143,7 @@ def compute_W0_lagged(N, alpha):
     n = N // 2 + 1
     beta = np.cosh(np.arccosh(pow(10.0, alpha)) / (N - 1))
 
-    W0 = np.zeros(n, dtype=np.complex256)
+    W0 = np.zeros(n, dtype=np.clongdouble)
     denominator = pow(10.0, alpha)
     factor = -pi * 1j * (N - 1) / N
     for k in range(0, n):
@@ -1209,29 +1209,29 @@ def resample(data, N_out, return_double=False):
             if return_double:
                 return np.array([], dtype=np.complex128)
             else:
-                return np.array([], dtype=np.complex256)
+                return np.array([], dtype=np.clongdouble)
         else:
             if return_double:
                 return np.array([], dtype=np.float64)
             else:
-                return np.array([], dtype=np.float128)
+                return np.array([], dtype=np.longdouble)
 
     if N_out == 1:
         # Return the average
         return np.array([sum(data) / N_in])
 
     if is_complex:
-        resampled = np.zeros(N_out, dtype=np.complex256)
+        resampled = np.zeros(N_out, dtype=np.clongdouble)
     else:
-        resampled = np.zeros(N_out, dtype=np.float128)
+        resampled = np.zeros(N_out, dtype=np.longdouble)
 
     if N_in == 2:
         # Linear interpolation.
         # If we've reached this point, we know that N_out >= 3.
         if is_complex:
-            diff = np.complex256(data[1]) - np.complex256(data[0])
+            diff = np.clongdouble(data[1]) - np.clongdouble(data[0])
         else:
-            diff = np.float128(data[1]) - np.float128(data[0])
+            diff = np.longdouble(data[1]) - np.longdouble(data[0])
         resampled = diff * np.array(range(N_out)) / (N_out - 1) + data[0]
 
     else:
@@ -1253,7 +1253,7 @@ def resample(data, N_out, return_double=False):
 
         sinc_length = min(N_min, 192) * long_sinc_taps_per_sample
         sinc_length -= (sinc_length + 1) % 2
-        sinc = np.zeros(sinc_length, dtype=np.float128)
+        sinc = np.zeros(sinc_length, dtype=np.longdouble)
         sinc[sinc_length // 2] = 1.0
 
         # Frequency resolution in units of frequency bins of sinc
@@ -1267,7 +1267,7 @@ def resample(data, N_out, return_double=False):
                 sinc[sinc_length // 2 - i] = \
                     np.sin(two_pi * ((f_cut * i) % 1)) / (two_pi * f_cut * i)
         else:
-            sinc = np.ones(sinc_length, dtype=np.float128)
+            sinc = np.ones(sinc_length, dtype=np.longdouble)
 
         # Apply a Kaiser window.  Note that the chosen cutoff frequency is below the
         # lower Nyquist rate just enough to be at the end of the main lobe.
@@ -1340,11 +1340,11 @@ def freqresp(filt, delay_samples=0, samples_per_lobe=8, return_double=False):
     # get better frequency resolution.
     N_prime = samples_per_lobe * N
     # Start with zeros
-    filt_prime = np.zeros(N_prime, dtype=np.float128)
+    filt_prime = np.zeros(N_prime, dtype=np.longdouble)
     # The beginning and end have filter coefficients
-    filt_prime[: N - delay_samples] = np.float128(filt[delay_samples:])
+    filt_prime[: N - delay_samples] = np.longdouble(filt[delay_samples:])
     if delay_samples > 0:
-        filt_prime[-delay_samples:] = np.float128(filt[:delay_samples])
+        filt_prime[-delay_samples:] = np.longdouble(filt[:delay_samples])
 
     # Now take an FFT
     return rfft(filt_prime, return_double=return_double)
