@@ -79,19 +79,66 @@ class ActuationModel(Model):
 
         for i, stage in enumerate(out.keys()):
             for j, quadrant in enumerate(out[stage].keys()):
-                if (hasattr(self, f'{stage.lower()}_driver_meas_z_{quadrant.lower()}') and
-                        hasattr(self, f'{stage.lower()}_driver_meas_p_{quadrant.lower()}')):
-                    zeros = np.asarray(
-                        getattr(self, f'{stage.lower()}_driver_meas_z_{quadrant.lower()}'))
-                    poles = np.asarray(
-                        getattr(self, f'{stage.lower()}_driver_meas_p_{quadrant.lower()}'))
-                    gain = np.prod(2.0*np.pi*poles) / np.prod(2.0*np.pi*zeros)
-                    model = signal.ZerosPolesGain(
-                        -2.0*np.pi*zeros,
-                        -2.0*np.pi*poles,
-                        gain)
-                    tf = signal.freqresp(model, 2.0*np.pi*frequencies)[1]
-                    out[stage][quadrant] = tf
+
+                # Emit error if trying to use the old format
+                if ((hasattr(self, f'{stage.lower()}_driver_meas_z_'
+                                   f'{quadrant.lower()}') and
+                     not hasattr(self, f'{stage.lower()}_driver_uncompensated_'
+                                       f'z_{quadrant.lower()}')) or
+                    (hasattr(self, f'{stage.lower()}_driver_meas_p_'
+                                   f'{quadrant.lower()}') and
+                     not hasattr(self, f'{stage.lower()}_driver_uncompensated_'
+                                       f'p_{quadrant.lower()}'))):
+                    raise KeyError(
+                        'Using old format for zeros and poles. Please check'
+                        ' your configuration string/file and use the'
+                        ' updated format to specify'
+                        ' compensted/uncompensated parameters.')
+
+                # Start with empty lists for zeros and poles. Extend as needed
+                zeros = []
+                poles = []
+                if (hasattr(self, f'{stage.lower()}_driver_uncompensated_z_'
+                                  f'{quadrant.lower()}') and
+                        hasattr(self, f'{stage.lower()}_driver_uncompensated_'
+                                      f'p_{quadrant.lower()}')):
+                    zeros.extend(getattr(
+                        self, f'{stage.lower()}_driver_uncompensated_z_'
+                              f'{quadrant.lower()}'))
+                    poles.extend(getattr(
+                        self, f'{stage.lower()}_driver_uncompensated_p_'
+                              f'{quadrant.lower()}'))
+                if (hasattr(self, f'{stage.lower()}_driver_compensated_z_'
+                                  f'{quadrant.lower()}') and
+                        getattr(self, f'{stage.lower()}_front_end_driver_'
+                                      f'compensation_{quadrant.lower()}') == 'OFF'):
+                    zeros.extend(getattr(self, f'{stage.lower()}_driver_'
+                                               f'compensated_z_{quadrant.lower()}'))
+                if (hasattr(self, f'{stage.lower()}_driver_compensated_p_'
+                                  f'{quadrant.lower()}') and
+                        getattr(self, f'{stage.lower()}_front_end_driver_'
+                                      f'compensation_{quadrant.lower()}') == 'OFF'):
+                    poles.extend(getattr(self, f'{stage.lower()}_driver_'
+                                               f'compensated_p_{quadrant.lower()}'))
+
+                # Convert lists to numpy arrays
+                zeros = np.asarray(zeros)
+                poles = np.asarray(poles)
+
+                # Gain is the ratio of poles / zeros
+                # NB: if both are empty, then this returns a gain of 1.0
+                gain = np.prod(2.0*np.pi*poles) / np.prod(2.0*np.pi*zeros)
+
+                # LTI model
+                model = signal.ZerosPolesGain(
+                    -2.0*np.pi*zeros,
+                    -2.0*np.pi*poles,
+                    gain)
+
+                # The frequency response of the LTI model saved to
+                # out[stage][quadrant]
+                tf = signal.freqresp(model, 2.0*np.pi*frequencies)[1]
+                out[stage][quadrant] = tf
 
         return out
 
@@ -140,6 +187,88 @@ class ActuationModel(Model):
 
         return self.tst_dc_gain_V2pct() * self.tst_npv2
 
+    def sus_digital_filters(self, frequencies):
+        """
+        The transfer function of the SUS digital filters
+
+        Parameters
+        ----------
+        frequencies : `float`, array-like
+            array of frequencies to compute the response
+
+        Returns
+        -------
+        tst_isc_inf_filter_response : `complex128`, array-like
+            transfer function response of the ISC_INF digital filters in the
+            TST path
+        tst_lock_filter_response : `complex128`, array-like
+            transfer function response of the LOCK digital filters in the
+            TST path
+        tst_drive_align_filter_response : `complex128`, array-like
+            transfer function response of the DRIVEALIGN digital filters in
+            the TST path
+        pum_lock_filter_response : `complex128`, array-like
+            transfer function response of the LOCK digital filters in the
+            PUM path
+        pum_drive_align_filter_response : `complex128`, array-like
+            transfer function response of the DRIVEALIGN digital filters in the
+             PUM path
+        uim_lock_filter_response : `complex128`, array-like
+            transfer function response of the LOCK digital filters in the UIM
+            path
+        uim_drive_align_filter_response : `complex128`, array-like
+            transfer function response of the DRIVEALIGN digital filters in the
+            UIM path
+        """
+
+        # Start with TST stage filters
+        tst_isc_inf_filter_response, pfilt = \
+            compute_digital_filter_response(
+                self.dpath(self.sus_filter_file),
+                self.tst_isc_inf_bank, self.tst_isc_inf_modules[0],
+                self.tst_isc_inf_gain, frequencies)
+        tst_lock_filter_response = \
+            compute_digital_filter_response(
+                self.dpath(self.sus_filter_file),
+                self.tst_lock_bank, self.tst_lock_modules[0],
+                self.tst_lock_gain, frequencies, pfilt)[0]
+        tst_drive_align_filter_response = \
+            compute_digital_filter_response(
+                self.dpath(self.sus_filter_file),
+                self.tst_drive_align_bank, self.tst_drive_align_modules[0],
+                self.tst_drive_align_gain, frequencies, pfilt)[0]
+
+        # The PUM stage feedback is to the same SUS as TST stage, so
+        # we can reuse the pfilt variable from above
+        pum_lock_filter_response = \
+            compute_digital_filter_response(
+                self.dpath(self.sus_filter_file),
+                self.pum_lock_bank, self.pum_lock_modules[0],
+                self.pum_lock_gain, frequencies, pfilt)[0]
+        pum_drive_align_filter_response = \
+            compute_digital_filter_response(
+                self.dpath(self.sus_filter_file),
+                self.pum_drive_align_bank, self.pum_drive_align_modules[0],
+                self.pum_drive_align_gain, frequencies, pfilt)[0]
+
+        # The UIM stage feedback is to the same SUS as PUM stage, so
+        # we can reuse the pfilt variable from above
+        uim_lock_filter_response = \
+            compute_digital_filter_response(
+                self.dpath(self.sus_filter_file),
+                self.uim_lock_bank, self.uim_lock_modules[0],
+                self.uim_lock_gain, frequencies, pfilt)[0]
+        uim_drive_align_filter_response = \
+            compute_digital_filter_response(
+                self.dpath(self.sus_filter_file),
+                self.uim_drive_align_bank, self.uim_drive_align_modules[0],
+                self.uim_drive_align_gain, frequencies, pfilt)[0]
+
+        return tst_isc_inf_filter_response, tst_lock_filter_response, \
+            tst_drive_align_filter_response, pum_lock_filter_response, \
+            pum_drive_align_filter_response, uim_lock_filter_response, \
+            uim_drive_align_filter_response
+
     def sus_digital_filters_response(self, frequencies):
         """
         The transfer function of the SUS digital filters
@@ -159,53 +288,20 @@ class ActuationModel(Model):
             transfer function response of the digital filters in the TST path
         """
 
+        tst_isc_inf_filter_response, tst_lock_filter_response, \
+            tst_drive_align_filter_response, pum_lock_filter_response, \
+            pum_drive_align_filter_response, uim_lock_filter_response, \
+            uim_drive_align_filter_response = \
+            self.sus_digital_filters(frequencies)
+
         # Start with TST stage filters
-        tst_isc_inf_filter_response, pfilt = \
-            compute_digital_filter_response(
-                self.dpath(self.sus_filter_file),
-                self.tst_isc_inf_bank, self.tst_isc_inf_modules[0],
-                self.tst_isc_inf_gain, frequencies)
-        tst_lock_filter_response = \
-            compute_digital_filter_response(
-                self.dpath(self.sus_filter_file),
-                self.tst_lock_bank, self.tst_lock_modules[0],
-                self.tst_lock_gain, frequencies, pfilt)[0]
-        tst_drive_align_filter_response = \
-            compute_digital_filter_response(
-                self.dpath(self.sus_filter_file),
-                self.tst_drive_align_bank, self.tst_drive_align_modules[0],
-                self.tst_drive_align_gain, frequencies, pfilt)[0]
         tst_digital_filter_response = tst_isc_inf_filter_response * \
             tst_lock_filter_response * tst_drive_align_filter_response
 
-        # The PUM stage feedback is to the same SUS as TST stage, so
-        # we can reuse the pfilt variable from above
-        pum_lock_filter_response = \
-            compute_digital_filter_response(
-                self.dpath(self.sus_filter_file),
-                self.pum_lock_bank, self.pum_lock_modules[0],
-                self.pum_lock_gain, frequencies, pfilt)[0]
-        pum_drive_align_filter_response = \
-            compute_digital_filter_response(
-                self.dpath(self.sus_filter_file),
-                self.pum_drive_align_bank, self.pum_drive_align_modules[0],
-                self.pum_drive_align_gain, frequencies, pfilt)[0]
         pum_digital_filter_response = tst_isc_inf_filter_response * \
             tst_lock_filter_response * pum_lock_filter_response * \
             pum_drive_align_filter_response
 
-        # The UIM stage feedback is to the same SUS as PUM stage, so
-        # we can reuse the pfilt variable from above
-        uim_lock_filter_response = \
-            compute_digital_filter_response(
-                self.dpath(self.sus_filter_file),
-                self.uim_lock_bank, self.uim_lock_modules[0],
-                self.uim_lock_gain, frequencies, pfilt)[0]
-        uim_drive_align_filter_response = \
-            compute_digital_filter_response(
-                self.dpath(self.sus_filter_file),
-                self.uim_drive_align_bank, self.uim_drive_align_modules[0],
-                self.uim_drive_align_gain, frequencies, pfilt)[0]
         uim_digital_filter_response = tst_isc_inf_filter_response * \
             tst_lock_filter_response * pum_lock_filter_response * \
             uim_lock_filter_response * uim_drive_align_filter_response
@@ -254,18 +350,37 @@ class ActuationModel(Model):
         pfilt = None
         for i, stage in enumerate(out.keys()):
             for j, quadrant in enumerate(out[stage].keys()):
-                if hasattr(self, f'{stage.lower()}_compensation_filter_bank_{quadrant.lower()}'):
+
+                # Emit error if trying to use the old format
+                if ((hasattr(self, f'{stage.lower()}_compensation_filter_bank_'
+                                   f'{quadrant.lower()}') and
+                     not hasattr(self, f'{stage.lower()}_filter_bank_'
+                                       f'{quadrant.lower()}')) or
+                    (hasattr(self, f'{stage.lower()}_compensation_filter_'
+                                   f'modules_in_use_{quadrant.lower()}') and
+                     not hasattr(self, f'{stage.lower()}_compensation_filter_'
+                                       f'modules_{quadrant.lower()}')) or
+                    (hasattr(self, f'{stage.lower()}_compensation_filter_gain_'
+                                   f'{quadrant.lower()}') and
+                     not hasattr(self, f'{stage.lower()}_filter_gain_{quadrant.lower()}'))):
+                    raise KeyError(
+                        'Using the old format for driver compensation'
+                        ' parameters. Please update your configuration'
+                        ' file/string to use the new format.')
+
+                if hasattr(self, f'{stage.lower()}_filter_bank_{quadrant.lower()}'):
                     bank = getattr(self,
-                                   f'{stage.lower()}_compensation_filter_bank_{quadrant.lower()}')
-                if hasattr(
-                        self,
-                        f'{stage.lower()}_compensation_filter_modules_in_use_{quadrant.lower()}'):
+                                   f'{stage.lower()}_filter_bank_{quadrant.lower()}')
+                if (hasattr(self, f'{stage.lower()}_compensation_filter_'
+                                  f'modules_{quadrant.lower()}') and
+                        getattr(self, f'{stage.lower()}_front_end_driver_'
+                                      f'compensation_{quadrant.lower()}') == 'OFF'):
                     modules = getattr(
                         self,
-                        f'{stage.lower()}_compensation_filter_modules_in_use_{quadrant.lower()}')
-                if hasattr(self, f'{stage.lower()}_compensation_filter_gain_{quadrant.lower()}'):
+                        f'{stage.lower()}_compensation_filter_modules_{quadrant.lower()}')
+                if hasattr(self, f'{stage.lower()}_filter_gain_{quadrant.lower()}'):
                     gain = getattr(
-                        self, f'{stage.lower()}_compensation_filter_gain_{quadrant.lower()}')
+                        self, f'{stage.lower()}_filter_gain_{quadrant.lower()}')
 
                 if ('bank' in locals() and len(bank) > 0 and
                         'modules' in locals() and 'gain' in locals()):
