@@ -816,7 +816,8 @@ class CALCSModel(DARMModel):
             array of frequencies to compute the CAL_DELTAL_EXTERNAL DTT
             calibration
         kwargs : optional
-            values are passed to `calcs.calcs_dtt_calibration()`
+            values are passed to `calcs.calcs_dtt_calibration()` and
+            `pcal.compute_pcal_correction()`
 
         Returns
         -------
@@ -824,8 +825,11 @@ class CALCSModel(DARMModel):
             transfer function resposne of the correction factor
         """
 
-        deltal_ext = self.calcs_dtt_calibration(frequencies, kwargs)
-        pcal_corr = self.pcal.compute_pcal_correction(frequencies)
+        endstation = kwargs.pop('endstation', False)
+
+        deltal_ext = self.calcs_dtt_calibration(frequencies, **kwargs)
+        pcal_corr = self.pcal.compute_pcal_correction(frequencies,
+                                                      endstation=endstation)
 
         tf = deltal_ext / pcal_corr
 
