@@ -733,7 +733,8 @@ class ProcessSensingMeasurement(ProcessMeasurement):
         frequencies : `float`, array-like
             frequency values of the transfer function, in units of Hz
         processed_measurement_response : `complex128`, array-like
-            transfer function response of the actuation function
+            transfer function response of the actuation function in units
+            of digital counts per meter of DARM
         processed_measurement_response_unc : `float`, array-like
             relative uncertainty of processed measurement data
         """
@@ -830,7 +831,12 @@ class ProcessSensingMeasurement(ProcessMeasurement):
         Returns
         -------
         chain : `float`, array-like
-            The MCMC chain
+            The MCMC chain where index:
+            - 0 is the gain in units of counts per meter of DARM
+            - 1 is the coupled cavity pole frequency in units of Hz
+            - 2 is the optical spring frequency in units of Hz
+            - 3 is the quality factor of the optical spring (Q, unitless)
+            - 4 is the residual time delay in units of seconds
         """
         global meas_type_gl, is_pro_spring_gl
         meas_type_gl = self.meas_type
@@ -1196,7 +1202,9 @@ class ProcessActuationMeasurement(ProcessMeasurement):
         frequencies : `float`, array-like
             frequency values of the transfer function, in units of Hz
         processed_measurement_response : `complex128`, array-like
-            transfer function response of the actuation function
+            transfer function response of the actuation function, in units of
+            newtons per driver output (amps or volts**2). For example, for TST
+            the units will be in N/V**2
         processed_measurement_response_unc : `float`, array-like
             relative uncertainty of processed measurement data
         """
@@ -1267,7 +1275,10 @@ class ProcessActuationMeasurement(ProcessMeasurement):
         Returns
         -------
         chain : `float`, array-like
-            The MCMC chain
+            The MCMC chain where index:
+            - 0 is the gain in units of newtons per driver output (amps or
+            volts**2). For example, for TST the units will be in N/V**2.
+            - 1 is the residual time delay in units of seconds
         """
         global meas_type_gl
         meas_type_gl = self.meas_type
