@@ -133,21 +133,52 @@ class SensingModel(Model):
         idx = self.omc_path_names.index(name)
         assert len(set(self.omc_path_names)) == len(self.omc_path_names)
 
-        # First the transimpedence amplifier is computed
-        if (hasattr(self, 'omc_meas_z_trans_amplifier') and
-                hasattr(self, 'omc_meas_p_trans_amplifier')):
-            if idx < len(self.omc_meas_z_trans_amplifier):
+        # Emit error if trying to use the old format
+        if ((hasattr(self, 'omc_meas_z_trans_amplifier') and
+             not hasattr(self, 'omc_meas_z_trans_amplifier_uncompensated')) or
+            (hasattr(self, 'omc_meas_p_trans_amplifier') and
+             not hasattr(self, 'omc_meas_p_trans_amplifier_uncompensated'))):
+            raise KeyError('Using old name format for zeros and poles. Please'
+                           ' check your configuration string/file and use the'
+                           ' updated format to specify'
+                           ' compensted/uncompensated parameters.')
+
+        # Transimpedence amplifier
+        # There are potentially two parts, the uncompensated zeros/poles and
+        # and (if the FE compensation is "OFF") the compensated zeros and
+        # poles. The compensated values are appended when present and
+        # "compensation" == "OFF"
+        if (hasattr(self, 'omc_meas_z_trans_amplifier_uncompensated') and
+                hasattr(self, 'omc_meas_p_trans_amplifier_uncompensated')):
+            if idx < len(self.omc_meas_z_trans_amplifier_uncompensated):
                 meas_z_trans_amp = np.asarray(
-                    self.omc_meas_z_trans_amplifier[idx])
+                    self.omc_meas_z_trans_amplifier_uncompensated[idx])
             else:
                 meas_z_trans_amp = np.asarray([])
             meas_p_trans_amp = np.asarray(
-                self.omc_meas_p_trans_amplifier[idx])
-        elif hasattr(self, 'omc_meas_p_trans_amplifier'):
+                self.omc_meas_p_trans_amplifier_uncompensated[idx])
+        elif hasattr(self, 'omc_meas_p_trans_amplifier_uncompensated'):
             meas_z_trans_amp = np.asarray([])
             meas_p_trans_amp = np.asarray(
-                self.omc_meas_p_trans_amplifier[idx])
+                self.omc_meas_p_trans_amplifier_uncompensated[idx])
+        if (self.omc_front_end_trans_amplifier_compensation[idx] == 'OFF' and
+                hasattr(self, 'omc_meas_z_trans_amplifier_compensated') and
+                idx < len(self.omc_meas_z_trans_amplifier_compensated)):
+            meas_z_trans_amp = np.append(
+                meas_z_trans_amp,
+                self.omc_meas_z_trans_amplifier_compensated[idx])
+        if (self.omc_front_end_trans_amplifier_compensation[idx] == 'OFF' and
+                hasattr(self, 'omc_meas_p_trans_amplifier_compensated') and
+                idx < len(self.omc_meas_p_trans_amplifier_compensated)):
+            meas_p_trans_amp = np.append(
+                meas_p_trans_amp,
+                self.omc_meas_p_trans_amplifier_compensated[idx])
+
+        # Double-check that there are less than or equal zeros and poles
         assert len(meas_z_trans_amp) <= len(meas_p_trans_amp)
+
+        # If at least one pole, then build the ZPK LTI filter and compute the
+        # frequency response
         if len(meas_p_trans_amp) > 0:
             omc_trans_amplifier_response = signal.freqresp(
                 signal.ZerosPolesGain(-2*np.pi*meas_z_trans_amp,
@@ -185,22 +216,60 @@ class SensingModel(Model):
         idx = self.omc_path_names.index(name)
         assert len(set(self.omc_path_names)) == len(self.omc_path_names)
 
-        # The zeros and poles need to have the name appended to them
+        # whitening mode name in use for this path
         whitening_name = getattr(self, 'whitening_mode_names')[idx]
-        if (hasattr(self, f'omc_meas_z_whitening_{whitening_name}') and
-                hasattr(self, f'omc_meas_p_whitening_{whitening_name}')):
-            zeros = getattr(self, f'omc_meas_z_whitening_{whitening_name}')
+
+        # Emit error if trying to use the old format
+        if ((hasattr(self, f'omc_meas_z_whitening_{whitening_name}') and
+             not hasattr(self, f'omc_meas_z_whitening_uncompensated_'
+                               f'{whitening_name}')) or
+            (hasattr(self, f'omc_meas_p_whitening_{whitening_name}') and
+             not hasattr(self, 'omc_meas_p_whitening_uncompensated_'
+                               f'{whitening_name}'))):
+            raise KeyError('Using old name format for zeros and poles. Please'
+                           ' check your configuration string/file and use the'
+                           ' updated format to specify'
+                           ' compensted/uncompensated parameters.')
+
+        # Whitening filter with mode name appended to the variables.
+        # There are potentially two parts, the uncompensated zeros/poles and
+        # and (if the FE compensation is "OFF") the compensated zeros and
+        # poles. The compensated values are appended when present and
+        # "compensation" == "OFF"
+        # The zeros and poles need to have the name appended to them
+        if (hasattr(self, f'omc_meas_z_whitening_uncompensated_{whitening_name}') and
+                hasattr(self, f'omc_meas_p_whitening_uncompensated_{whitening_name}')):
+            zeros = getattr(self, f'omc_meas_z_whitening_uncompensated_{whitening_name}')
             if idx < len(zeros):
                 meas_z_whitening = np.asarray(zeros[idx])
             else:
                 meas_z_whitening = np.asarray([])
-            poles = getattr(self, f'omc_meas_p_whitening_{whitening_name}')
+            poles = getattr(self, f'omc_meas_p_whitening_uncompensated_{whitening_name}')
             meas_p_whitening = np.asarray(poles[idx])
-        elif getattr(self, f'omc_meas_p_whitening_{whitening_name}'):
+        elif getattr(self, f'omc_meas_p_whitening_uncompensated_{whitening_name}'):
             meas_z_whitening = np.asarray([])
-            poles = getattr(self, f'omc_meas_p_whitening_{whitening_name}')
+            poles = getattr(self, f'omc_meas_p_whitening_uncompensated_{whitening_name}')
             meas_p_whitening = np.asarray(poles[idx])
+        if (hasattr(self, f'omc_meas_z_whitening_compensated_{whitening_name}') and
+                getattr(self, f'omc_front_end_whitening_compensation'
+                              f'_{whitening_name}')[idx] == 'OFF' and
+                idx < len(getattr(self, f'omc_meas_z_whitening_compensated_{whitening_name}'))):
+            meas_z_whitening = np.append(
+                meas_z_whitening,
+                getattr(self, f'omc_meas_z_whitening_compensated_{whitening_name}')[idx])
+        if (hasattr(self, f'omc_meas_p_whitening_compensated_{whitening_name}') and
+                getattr(self, f'omc_front_end_whitening_compensation'
+                              f'_{whitening_name}')[idx] == 'OFF' and
+                idx < len(getattr(self, f'omc_meas_p_whitening_compensated_{whitening_name}'))):
+            meas_p_whitening = np.append(
+                meas_p_whitening,
+                getattr(self, f'omc_meas_p_whitening_compensated_{whitening_name}]')[idx])
+
+        # Double-check that there are less than or equal zeros and poles
         assert len(meas_z_whitening) <= len(meas_p_whitening)
+
+        # If at least one pole, then build the ZPK LTI filter and compute the
+        # frequency response
         if len(meas_p_whitening) > 0:
             omc_whitening_response = signal.freqresp(
                 signal.ZerosPolesGain(-2*np.pi*meas_z_whitening,
@@ -263,7 +332,7 @@ class SensingModel(Model):
                 analog_aa_filter_response_hi_f *
                 super_high_frequency_poles_apparent_delay)
 
-    def omc_digital_compensation_response(self, name, frequencies):
+    def omc_digital_filters_response(self, name, frequencies):
         """
         The transfer function of the OMC digital compensation filters
 
@@ -278,44 +347,62 @@ class SensingModel(Model):
 
         Returns
         -------
-        compensation_response : `complex128`, array-like
-            transfer function response of the digital compensation filters in
-            the path labeled by `name`
+        filter_response : `complex128`, array-like
+            transfer function response of the digital filters in the path
+            labeled by `name`
         """
 
         idx = self.omc_path_names.index(name)
         assert len(set(self.omc_path_names)) == len(self.omc_path_names)
 
-        # Always return a compensation of 1 for all frequencies if nothing is
+        whitening_name = getattr(self, 'whitening_mode_names')[idx]
+
+        # Always return a response of 1 for all frequencies if nothing is
         # provided in the configuration
-        compensation_response = np.ones(len(frequencies), dtype='complex128')
+        filter_response = np.ones(len(frequencies), dtype='complex128')
 
-        # If filter file provided and filter bank provided with at least one
-        # element, then we'll get a transfer function
-        if (hasattr(self, 'omc_compensation_filter_file') and
-                self.omc_compensation_filter_file != '' and
-                len(self.omc_compensation_filter_bank) > idx and
-                self.omc_compensation_filter_bank[idx] != '' and
-                len(self.omc_compensation_filter_modules_in_use) > idx and
-                self.omc_compensation_filter_modules_in_use[idx] != '' and
-                len(self.omc_compensation_filter_gain) > idx and
-                self.omc_compensation_filter_gain[idx] != ''):
-            tf, pfilt = compute_digital_filter_response(
-                self.dpath(self.omc_compensation_filter_file),
-                self.omc_compensation_filter_bank[idx],
-                self.omc_compensation_filter_modules_in_use[idx],
-                self.omc_compensation_filter_gain[idx],
+        # To get a transfer function with gain only, there needs to be:
+        # 0) list of path names and this function specifying which path name
+        # 1) a valid omc_filter_file
+        # 2) a valid omc_filter_bank string for the specified path
+        # 3) a floating point omc_filter_gain value for the specified path
+        # To get filter modules in addition to the above we need to have one
+        # or more of the following for the specified path:
+        # 4a) omc_filter_noncompensating_modules
+        # 4b) omc_trans_amplifier_compensation_modules
+        # 4c) omc_whitening_compensation_modules_<whitening_mode_name>
+        # omc_front_end_trans_amplifier_compensation ON/OFF controls if 4b is
+        # included while
+        # omc_front_end_whitening_compensation_<whitening_mode_name> ON/OFF
+        # controls if 4c is included.
+        if (hasattr(self, 'omc_filter_file') and
+                self.omc_filter_file != '' and
+                len(self.omc_filter_bank) > idx and
+                self.omc_filter_bank[idx] != '' and
+                len(self.omc_filter_gain) > idx and
+                self.omc_filter_gain[idx] != ''):
+            modules = []
+            if (len(self.omc_filter_noncompensating_modules) > idx and
+                    self.omc_filter_noncompensating_modules[idx] != ''):
+                modules.extend(self.omc_filter_noncompensating_modules[idx])
+            if (hasattr(self, 'omc_trans_amplifier_compensation_modules') and
+                    self.omc_front_end_trans_amplifier_compensation[idx] == 'OFF'):
+                modules.extend(self.omc_trans_amplifier_compensation_modules[idx])
+            if (hasattr(self, f'omc_whitening_compensation_modules_{whitening_name}') and
+                    getattr(self, f'omc_front_end_whitening_compensation'
+                                  f'_{whitening_name}')[idx] == 'OFF'):
+                modules.extend(getattr(
+                    self,
+                    f'omc_whitening_compensation_modules_{whitening_name}')[idx])
+            tf, _ = compute_digital_filter_response(
+                self.dpath(self.omc_filter_file),
+                self.omc_filter_bank[idx],
+                modules,
+                self.omc_filter_gain[idx],
                 frequencies)
-            compensation_response *= tf
-        elif (hasattr(self, 'omc_compensation_filter_file') and
-                self.omc_compensation_filter_file != '' and
-                len(self.omc_compensation_filter_bank) > idx and
-                self.omc_compensation_filter_bank[idx] != '' and
-                len(self.omc_compensation_filter_gain) > idx and
-                self.omc_compensation_filter_gain[idx] != ''):
-            compensation_response *= self.omc_compensation_filter_gain[idx]
+            filter_response *= tf
 
-        return compensation_response
+        return filter_response
 
     def omc_path_response(self, name, frequencies):
         """
@@ -352,7 +439,7 @@ class SensingModel(Model):
         adc_gain = self.adc_gain[idx]
 
         # front end digital compensation of analog OMC electronics
-        omc_fe_tf = self.omc_digital_compensation_response(name, frequencies)
+        omc_fe_tf = self.omc_digital_filters_response(name, frequencies)
 
         # digital anti-aliasing filter
         digital_aa_filter_response = \
