@@ -630,7 +630,7 @@ class DARMUncertainty(object):
             this_sensing = [darm_copy.sensing.coupled_cavity_optical_gain,
                             darm_copy.sensing.coupled_cavity_pole_frequency,
                             darm_copy.sensing.detuned_spring_frequency,
-                            1/darm_copy.sensing.detuned_spring_q,
+                            darm_copy.sensing.detuned_spring_q,
                             0]
 
         # Sample sensing GPR; we'll be sampling the actuation GPR later
@@ -749,7 +749,7 @@ class DARMUncertainty(object):
         darm_copy.sensing.coupled_cavity_optical_gain = this_kappa_c * this_sensing[0]
         darm_copy.sensing.coupled_cavity_pole_frequency = this_f_cc
         darm_copy.sensing.detuned_spring_frequency = this_sensing[2]
-        darm_copy.sensing.detuned_spring_q = 1/this_sensing[3]
+        darm_copy.sensing.detuned_spring_q = this_sensing[3]
         darm_copy.sensing.single_pole_approximation_delay_correction += \
             this_sensing[4]
 
@@ -788,27 +788,27 @@ class DARMUncertainty(object):
                         # Assignments to darm_copy object
                         if n == 0 and m == 1:
                             darm_copy.actuation.xarm.uim_npa *= (
-                                mcmc_sample_gain / self.model.actuation.xarm.uim_npa)
+                                mcmc_sample_gain / self.darm.actuation.xarm.uim_npa)
                             darm_copy.actuation.xarm.uim_delay += mcmc_sample_delay
                         elif n == 0 and m == 2:
                             darm_copy.actuation.xarm.pum_npa *= (
-                                mcmc_sample_gain / self.model.actuation.xarm.pum_npa)
+                                mcmc_sample_gain / self.darm.actuation.xarm.pum_npa)
                             darm_copy.actuation.xarm.pum_delay += mcmc_sample_delay
                         elif n == 0 and m == 3:
                             darm_copy.actuation.xarm.tst_npv2 *= (
-                                mcmc_sample_gain / self.model.actuation.xarm.tst_npv2)
+                                mcmc_sample_gain / self.darm.actuation.xarm.tst_npv2)
                             darm_copy.actuation.xarm.tst_delay += mcmc_sample_delay
                         elif n == 1 and m == 1:
                             darm_copy.actuation.yarm.uim_npa *= (
-                                mcmc_sample_gain / self.model.actuation.yarm.uim_npa)
+                                mcmc_sample_gain / self.darm.actuation.yarm.uim_npa)
                             darm_copy.actuation.yarm.uim_delay += mcmc_sample_delay
                         elif n == 1 and m == 2:
                             darm_copy.actuation.yarm.pum_npa *= (
-                                mcmc_sample_gain / self.model.actuation.yarm.pum_npa)
+                                mcmc_sample_gain / self.darm.actuation.yarm.pum_npa)
                             darm_copy.actuation.yarm.pum_delay += mcmc_sample_delay
                         elif n == 1 and m == 3:
                             darm_copy.actuation.yarm.tst_npv2 *= (
-                                mcmc_sample_gain / self.model.actuation.yarm.tst_npv2)
+                                mcmc_sample_gain / self.darm.actuation.yarm.tst_npv2)
                             darm_copy.actuation.yarm.tst_delay += mcmc_sample_delay
 
                     # Sample gpr if a file was given
@@ -1095,7 +1095,11 @@ class DARMUncertainty(object):
             f2.semilogx(frequencies, 180 / np.pi * (response_pha_quant[j, :]), label=legendLabel)
         f1.set_xlabel('Frequency [Hz]')
         f2.set_xlabel('Frequency [Hz]')
+        f1.set_xlim(10, 2000)
+        f2.set_xlim(10, 2000)
         f1.set_ylabel('Magnitude')
         f2.set_ylabel('Phase [deg.]')
+        f1.set_ylim(-10, 10)
+        f2.set_ylim(-10, 10)
         if filename is not None:
-            plt.savefig(filename)
+            plt.savefig(filename, bbox_inches='tight')
