@@ -677,3 +677,47 @@ def read_gpr_from_hdf5(filename, measurement):
         frequencies = meas.get('frequencies')[()]
 
     return meas_model, y_pred, cov, frequencies
+
+
+def read_eta_or_syserr_from_hdf5(filename, measurement=None, sensing=False, actuation=False):
+    """
+    Read eta results(See aLOG:62621) or sensing and actuation systematic error defined by user
+    from an HDF5 file
+
+    Parameters
+    ----------
+    filename : str
+        Output filename
+    measurement : str
+        Either 'sensing' or 'actuation' or 'filename'
+    sensing : boolen
+    actuation : boolen
+
+    Returns
+    -------
+    frequencies : `float`, array-like
+        Array of frequencies the eta result is valid for
+    syserr : dict
+        dictionary of systematic error for this arm and stage
+    """
+
+    with h5py.File(filename, 'r') as f:
+
+        if measurement is not None:
+            assert measurement == \
+                list(f.keys())[0], f'{measurement} is not an hdf5 group in {filename}'
+            frequencies = np.array(f.get('freq')[()], dtype=float)
+            syserr = np.array(f.get(measurement)[()], dtype=complex)
+
+        if sensing:
+            frequencies = np.array(f.get('frequencies')[()], dtype=float)
+            syserr = np.array(f.get('sensing_syserr')[()], dtype=complex)
+
+        if actuation:
+            frequencies = np.array(f.get('frequencies')[()], dtype=float)
+            syserr = {'xarm': {}, 'yarm': {}}
+            for i, arm in enumerate(syserr.keys()):
+                for j, stage in enumerate(syserr[arm].keys()):
+                    syserr[arm][stage] = f.get(f'{arm}/{stage}')[()]
+
+    return frequencies, syserr
