@@ -53,14 +53,14 @@ class TestAnalogDriverResponse(unittest.TestCase):
 [metadata]
 [interferometer]
 [actuation_x_arm]
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR =
-tst_driver_meas_Z_LR =
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR =
-tst_driver_meas_P_LR =
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR =
+tst_driver_uncompensated_Z_LR =
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR =
+tst_driver_uncompensated_P_LR =
 ''',
                                             measurement='actuation_x_arm')
 
@@ -238,6 +238,174 @@ tst_NpV2 = 4.427e-11
         self.assertAlmostEqual(tst_gain, self.known_tst_dc_gain)
 
 
+class TestSUSDigitalFilters(unittest.TestCase):
+
+    def setUp(self):
+        # Pre-defined values
+        self.frequencies = np.logspace(0, np.log10(5000.), 10)
+        self.tst_isc_inf_filter_response = np.array(
+            [1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j])
+        self.tst_lock_filter_response = np.array(
+            [0.999995665359871-0.000272790003103j,
+             0.999995496265676-0.000702789632297j,
+             0.999994373922495-0.001810604217536j,
+             0.999986924147203-0.004664770123548j,
+             0.999937459270884-0.012019700386180j,
+             0.999608338031661-0.030997995364512j,
+             0.997387781574251-0.080406381478687j,
+             0.980886105795703-0.217157945258743j,
+             0.638188154184932-0.898259426552110j,
+             0.707847556914040+0.798465985670971j])
+        self.tst_drive_align_filter_response = np.array(
+            [-0.031382125001088+0.305163415820658j,
+             2.425639846913828+0.541266964013526j,
+             4.772436789791023-14.431858429029758j,
+             -10.799493075302230-21.659812735113267j,
+             -31.182515810388480-18.548259489461532j,
+             -39.526836812833459-6.894921607809322j,
+             -36.129734307732122-0.266960569021572j,
+             -35.682495450563579-0.320690652602195j,
+             -35.696331063875391-0.134563202055048j,
+             -35.699846481043664-0.037488662354112j])
+        self.pum_lock_filter_response = np.array(
+            [-0.157592900352767+0.127863513836283j,
+             -2.826004221047697+0.243072450878951j,
+             -28.982811336208435+1.154255573110084j,
+             -199.257228525459169+19.053501528584700j,
+             -1309.778579816084402+329.356447710530347j,
+             -7333.646298110769749+6093.483160258686439j,
+             29683.804497749919392+27721.559707795226132j,
+             29263.012403179542162+14747.370377871528035j,
+             26716.549838518367324-14947.643675827408515j,
+             3964.230336695232381-11028.505558133558225j])
+        self.pum_drive_align_filter_response = np.array(
+            [1.007811710686028-0.002244893005650j,
+             1.061673400011530-0.014847884581376j,
+             1.072155888474460-0.422340584495491j,
+             0.652165100671343-0.605111854260755j,
+             0.083870120634454-0.507781585073636j,
+             -0.137921317637276-0.162320031347624j,
+             -0.011808103201744+0.002762524811938j,
+             0.000584567255433-0.005925249411234j,
+             0.001359953413426-0.002900713040568j,
+             0.000094860790992-0.000924075886957j])
+        self.uim_lock_filter_response = np.array(
+            [0.003812890441709-0.010711971680203j,
+             0.005023211450190+0.005667020241205j,
+             0.014779885019662+0.027004020822383j,
+             0.086070868465663+0.022181985878403j,
+             0.022327336104072-0.040946207260487j,
+             0.002880776234144-0.016580573534908j,
+             0.000421760000215-0.006429875356407j,
+             0.000062535339517-0.002480687522224j,
+             0.000008679381355-0.000924441210796j,
+             0.000000651564638-0.000253298362886j])
+        self.uim_drive_align_filter_response = np.array(
+            [1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j,
+             1.000000000000000+0.000000000000000j])
+
+    def tearDown(self):
+        del self.frequencies
+        del self.tst_isc_inf_filter_response
+        del self.tst_lock_filter_response
+        del self.tst_drive_align_filter_response
+        del self.pum_lock_filter_response
+        del self.pum_drive_align_filter_response
+        del self.uim_lock_filter_response
+        del self.uim_drive_align_filter_response
+
+    def test_sus_digital_filters_response(self):
+        A = pydarm.actuation.ActuationModel('''
+[metadata]
+[interferometer]
+[actuation_x_arm]
+sus_filter_file = test/H1SUSETMX_1236641144.txt
+tst_isc_inf_bank = ETMX_L3_ISCINF_L
+tst_isc_inf_modules =
+tst_isc_inf_gain = 1.0
+tst_lock_bank = ETMX_L3_LOCK_L
+tst_lock_modules = 5,8,9,10
+tst_lock_gain = 1.0
+tst_drive_align_bank = ETMX_L3_DRIVEALIGN_L2L
+tst_drive_align_modules = 4,5
+tst_drive_align_gain = -35.7
+pum_lock_bank = ETMX_L2_LOCK_L
+pum_lock_modules = 7
+pum_lock_gain = 23.0
+pum_drive_align_bank = ETMX_L2_DRIVEALIGN_L2L
+pum_drive_align_modules = 6,7
+pum_drive_align_gain = 1.0
+uim_lock_bank = ETMX_L1_LOCK_L
+uim_lock_modules = 10
+uim_lock_gain = 1.06
+uim_drive_align_bank = ETMX_L1_DRIVEALIGN_L2L
+uim_drive_align_modules =
+uim_drive_align_gain = 1.0
+''',
+                                            measurement='actuation_x_arm')
+        [tst_isc_inf_filter_response, tst_lock_filter_response,
+         tst_drive_align_filter_response, pum_lock_filter_response,
+         pum_drive_align_filter_response, uim_lock_filter_response,
+         uim_drive_align_filter_response] = \
+            A.sus_digital_filters(self.frequencies)
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(np.abs(tst_isc_inf_filter_response[n]),
+                                   np.abs(self.tst_isc_inf_filter_response[n]))
+            self.assertAlmostEqual(
+                np.angle(tst_isc_inf_filter_response[n], deg=True),
+                np.angle(self.tst_isc_inf_filter_response[n], deg=True))
+            self.assertAlmostEqual(np.abs(tst_lock_filter_response[n]),
+                                   np.abs(self.tst_lock_filter_response[n]))
+            self.assertAlmostEqual(
+                np.angle(tst_lock_filter_response[n], deg=True),
+                np.angle(self.tst_lock_filter_response[n], deg=True))
+            self.assertAlmostEqual(np.abs(tst_drive_align_filter_response[n]),
+                                   np.abs(
+                                       self.tst_drive_align_filter_response[n]))
+            self.assertAlmostEqual(
+                np.angle(tst_drive_align_filter_response[n], deg=True),
+                np.angle(self.tst_drive_align_filter_response[n], deg=True))
+            self.assertAlmostEqual(np.abs(pum_lock_filter_response[n]),
+                                   np.abs(self.pum_lock_filter_response[n]))
+            self.assertAlmostEqual(
+                np.angle(pum_lock_filter_response[n], deg=True),
+                np.angle(self.pum_lock_filter_response[n], deg=True))
+            self.assertAlmostEqual(np.abs(pum_drive_align_filter_response[n]),
+                                   np.abs(
+                                       self.pum_drive_align_filter_response[n]))
+            self.assertAlmostEqual(
+                np.angle(pum_drive_align_filter_response[n], deg=True),
+                np.angle(self.pum_drive_align_filter_response[n], deg=True))
+            self.assertAlmostEqual(np.abs(uim_lock_filter_response[n]),
+                                   np.abs(self.uim_lock_filter_response[n]))
+            self.assertAlmostEqual(
+                np.angle(uim_lock_filter_response[n], deg=True),
+                np.angle(self.uim_lock_filter_response[n], deg=True))
+            self.assertAlmostEqual(np.abs(uim_drive_align_filter_response[n]),
+                                   np.abs(
+                                       self.uim_drive_align_filter_response[n]))
+            self.assertAlmostEqual(
+                np.angle(uim_drive_align_filter_response[n], deg=True),
+                np.angle(self.uim_drive_align_filter_response[n], deg=True))
+
+
 class TestSUSDigitalFiltersResponse(unittest.TestCase):
 
     def setUp(self):
@@ -363,9 +531,10 @@ class TestSUSDigitalCompensationResponse(unittest.TestCase):
 [interferometer]
 [actuation_x_arm]
 sus_filter_file = test/H1SUSETMX_1236641144.txt
-tst_compensation_filter_bank_UL =
-tst_compensation_filter_modules_in_use_UL =
-tst_compensation_filter_gain_UL =
+tst_filter_bank_UL =
+tst_compensation_filter_modules_UL =
+tst_filter_gain_UL =
+tst_front_end_driver_compensation_UL = ON
 ''',
                                             measurement='actuation_x_arm')
 
@@ -410,14 +579,14 @@ class TestCombineSusQuadrants(unittest.TestCase):
 [metadata]
 [interferometer]
 [actuation_x_arm]
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR =
-tst_driver_meas_Z_LR =
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR =
-tst_driver_meas_P_LR =
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR =
+tst_driver_uncompensated_Z_LR =
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR =
+tst_driver_uncompensated_P_LR =
 ''',
                                             measurement='actuation_x_arm')
 
@@ -567,14 +736,16 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation = ON
+pum_front_end_driver_compensation = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -621,14 +792,17 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation = ON
+pum_front_end_driver_compensation = ON
+uim_front_end_driver_compensation = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -802,14 +976,17 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation = ON
+pum_front_end_driver_compensation = ON
+uim_front_end_driver_compensation = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -896,14 +1073,17 @@ tst_drive_align_bank = ETMX_L3_DRIVEALIGN_L2L
 tst_drive_align_modules = 4,5
 tst_drive_align_gain = -35.7
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation = ON
+pum_front_end_driver_compensation = ON
+uim_front_end_driver_compensation = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -979,14 +1159,17 @@ tst_drive_align_bank = ETMX_L3_DRIVEALIGN_L2L
 tst_drive_align_modules = 4,5
 tst_drive_align_gain = -35.7
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation = ON
+pum_front_end_driver_compensation = ON
+uim_front_end_driver_compensation = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -1063,14 +1246,17 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation = ON
+pum_front_end_driver_compensation = ON
+uim_front_end_driver_compensation = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -1162,14 +1348,17 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation = ON
+pum_front_end_driver_compensation = ON
+uim_front_end_driver_compensation = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -1211,14 +1400,17 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation = ON
+pum_front_end_driver_compensation = ON
+uim_front_end_driver_compensation = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
