@@ -132,19 +132,21 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 super_high_frequency_poles_apparent_delay = 0, 0
 adc_gain = 1638.001638001638, 1638.001638001638
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A, OMC_DCPD_B
-omc_compensation_filter_modules_in_use = 4: 4
-omc_compensation_filter_gain = 1, 1
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A, OMC_DCPD_B
+omc_filter_noncompensating_modules = 4: 4
+omc_filter_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [calcs]
 foton_invsensing_tf = \
   test/2019-04-04_H1CALCS_InverseSensingFunction_Foton_SRCD-2N_Gain_tf.txt
@@ -457,14 +459,14 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 31.5e3
-tst_driver_meas_P_LL = 26.7e3
-tst_driver_meas_P_UR = 26.6e3
-tst_driver_meas_P_LR = 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 31.5e3
+tst_driver_uncompensated_P_LL = 26.7e3
+tst_driver_uncompensated_P_UR = 26.6e3
+tst_driver_uncompensated_P_LR = 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -673,14 +675,14 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 31.5e3
-tst_driver_meas_P_LL = 26.7e3
-tst_driver_meas_P_UR = 26.6e3
-tst_driver_meas_P_LR = 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 31.5e3
+tst_driver_uncompensated_P_LL = 26.7e3
+tst_driver_uncompensated_P_UR = 26.6e3
+tst_driver_uncompensated_P_LR = 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -766,23 +768,25 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 super_high_frequency_poles_apparent_delay = 0, 0
 adc_gain = 1638.001638001638, 1638.001638001638
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A, OMC_DCPD_B
-omc_compensation_filter_modules_in_use = 4: 4
-omc_compensation_filter_gain = 1, 1
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A, OMC_DCPD_B
+omc_filter_noncompensating_modules = 4: 4
+omc_filter_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [digital]
 digital_filter_file = test/H1OMC_1239468752.txt
 digital_filter_bank = LSC_DARM1, LSC_DARM2
-digital_filter_modules_in_use = 1,2,3,4,7,9,10: 3,4,5,6,7
+digital_filter_modules = 1,2,3,4,7,9,10: 3,4,5,6,7
 digital_filter_gain = 400,1
 [actuation]
 darm_output_matrix = 1.0, -1.0, 0.0, 0.0
@@ -794,14 +798,14 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 31.5e3
-tst_driver_meas_P_LL = 26.7e3
-tst_driver_meas_P_UR = 26.6e3
-tst_driver_meas_P_LR = 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 31.5e3
+tst_driver_uncompensated_P_LL = 26.7e3
+tst_driver_uncompensated_P_UR = 26.6e3
+tst_driver_uncompensated_P_LR = 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -913,23 +917,25 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 super_high_frequency_poles_apparent_delay = 0, 0
 adc_gain = 1638.001638001638, 1638.001638001638
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A, OMC_DCPD_B
-omc_compensation_filter_modules_in_use = 4: 4
-omc_compensation_filter_gain = 1, 1
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A, OMC_DCPD_B
+omc_filter_noncompensating_modules = 4: 4
+omc_filter_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [digital]
 digital_filter_file = test/H1OMC_1239468752.txt
 digital_filter_bank = LSC_DARM1, LSC_DARM2
-digital_filter_modules_in_use = 1,2,3,4,7,9,10: 3,4,5,6,7
+digital_filter_modules = 1,2,3,4,7,9,10: 3,4,5,6,7
 digital_filter_gain = 400,1
 [actuation]
 darm_output_matrix = 1.0, -1.0, 0.0, 0.0
@@ -941,14 +947,14 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 31.5e3
-tst_driver_meas_P_LL = 26.7e3
-tst_driver_meas_P_UR = 26.6e3
-tst_driver_meas_P_LR = 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 31.5e3
+tst_driver_uncompensated_P_LL = 26.7e3
+tst_driver_uncompensated_P_UR = 26.6e3
+tst_driver_uncompensated_P_LR = 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -1012,16 +1018,16 @@ foton_delay_filter_tf = test/H1CALCS_8_CLK_DELAY.txt
              -6.479370603503953e-13+7.062109756021947e-13j,
              8.255633601165232e-13+3.1898890750452897e-13j])
         self.known_correction = np.array(
-            [0.08050209475040816-1.6513476841862913j,
-             5.520955244198903-5.39432597631647j,
-             42.86576723694163-12.95206706562494j,
-             286.2976701235751-29.870138626022648j,
-             1989.2449225789353+25.625179916953805j,
-             13324.518167327555-256.1410730974964j,
-             83043.27111119543+8600.650901100558j,
-             550117.5295480754+134754.87628064284j,
-             3020136.055721985+2211463.562530411j,
-             -2232612.4359687367+21856221.21387424j])
+            [-0.0008501089862348232-0.0003863633736571571j,
+             -1.7116997942422424e-05-7.969078324489177e-06j,
+             -1.238116795723849e-07-4.199824052455882e-07j,
+             1.9489520393474323e-08-6.143763314670491e-10j,
+             -5.7662915446536716e-09+2.38094579579211e-09j,
+             2.7970665627508423e-10-1.6315937801218042e-08j,
+             7.545157306911198e-08-4.156187896590543e-08j,
+             5.689969540529809e-07+3.095147054562399e-09j,
+             3.203791528674027e-06+1.940085939941273e-06j,
+            -1.7077191837064583e-06+2.1903105417274858e-05j])
 
     def tearDown(self):
         del self.frequencies
