@@ -32,7 +32,7 @@ class TestComputeDigitalFilterResponse(unittest.TestCase):
 [digital]
 digital_filter_file = test/H1OMC_1239468752.txt
 digital_filter_bank = LSC_DARM1, LSC_DARM2
-digital_filter_modules_in_use = 1,2,3,4,7,9,10: 3,4,5,6,7
+digital_filter_modules = 1,2,3,4,7,9,10: 3,4,5,6,7
 digital_filter_gain = 400,1
 ''')
         test_response = D.compute_response(
@@ -87,19 +87,21 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1638.001638001638, 1638.001638001638
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A, OMC_DCPD_B
-omc_compensation_filter_modules_in_use = 4: 4
-omc_compensation_filter_gain = 1, 1
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A, OMC_DCPD_B
+omc_filter_noncompensating_modules = 4: 4
+omc_filter_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 
 [actuation_x_arm]
 darm_feedback_sign = -1
@@ -107,14 +109,14 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -158,7 +160,7 @@ darm_feedback_y = OFF, OFF, OFF, OFF
 [digital]
 digital_filter_file = test/H1OMC_1239468752.txt
 digital_filter_bank = LSC_DARM1, LSC_DARM2
-digital_filter_modules_in_use = 1,2,3,4,7,9,10: 3,4,5,6,7
+digital_filter_modules = 1,2,3,4,7,9,10: 3,4,5,6,7
 digital_filter_gain = 400,1
 ''')
         test_olg = darm.compute_darm_olg(self.frequencies)
@@ -208,15 +210,17 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 
 [actuation_x_arm]
 darm_feedback_sign = -1
@@ -224,14 +228,14 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -275,7 +279,7 @@ darm_feedback_y = OFF, OFF, OFF, OFF
 [digital]
 digital_filter_file = test/H1OMC_1239468752.txt
 digital_filter_bank = LSC_DARM1, LSC_DARM2
-digital_filter_modules_in_use = 1,2,3,4,7,9,10: 3,4,5,6,7
+digital_filter_modules = 1,2,3,4,7,9,10: 3,4,5,6,7
 digital_filter_gain = 400,1
 '''
         darm = pydarm.darm.DARMModel(model_string)
@@ -350,15 +354,17 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 
 [actuation_x_arm]
 darm_feedback_sign = -1
@@ -366,14 +372,14 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -424,7 +430,7 @@ anti_aliasing_method = biquad
 [digital]
 digital_filter_file = test/H1OMC_1239468752.txt
 digital_filter_bank = LSC_DARM1, LSC_DARM2
-digital_filter_modules_in_use = 1,2,3,4,7,9,10: 3,4,5,6,7
+digital_filter_modules = 1,2,3,4,7,9,10: 3,4,5,6,7
 digital_filter_gain = 400,1
 '''
         darm = pydarm.darm.DARMModel(model_string)
@@ -493,15 +499,17 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 
 [actuation_x_arm]
 darm_feedback_sign = -1
@@ -509,14 +517,14 @@ tst_NpV2 = 4.427e-11
 linearization = OFF
 actuation_esd_bias_voltage = -9.3
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 anti_imaging_rate_string = 16k
@@ -560,7 +568,7 @@ darm_feedback_y = OFF, OFF, OFF, OFF
 [digital]
 digital_filter_file = test/H1OMC_1239468752.txt
 digital_filter_bank = LSC_DARM1, LSC_DARM2
-digital_filter_modules_in_use = 1,2,3,4,7,9,10: 3,4,5,6,7
+digital_filter_modules = 1,2,3,4,7,9,10: 3,4,5,6,7
 digital_filter_gain = 400,1
 '''
         darm = pydarm.darm.DARMModel(model_string)
