@@ -204,15 +204,17 @@ sensing_sign = 1
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [pcal]
 pcal_dewhiten               = 1.0, 1.0
 ref_pcal_2_darm_act_sign    = -1.0
@@ -319,15 +321,17 @@ sensing_sign = 1
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [pcal]
 pcal_dewhiten               = 1.0, 1.0
 ref_pcal_2_darm_act_sign    = -1.0
@@ -444,15 +448,17 @@ is_pro_spring = False
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [pcal]
 pcal_dewhiten               = 1.0, 1.0
 ref_pcal_2_darm_act_sign    = -1.0
@@ -497,7 +503,7 @@ anti_aliasing_method      = biquad
                 optical_pars[4], self.known_optical_pars[4], places=1)
         self.assertAlmostEqual(std_vals[0] / self.known_std[0], 1.0, places=1)
         self.assertAlmostEqual(std_vals[1] / self.known_std[1], 1.0, places=1)
-        self.assertAlmostEqual(std_vals[2] / self.known_std[2], 1.0, places=1)
+        self.assertAlmostEqual(std_vals[2] / self.known_std[2], 1.0, delta=0.1)
         self.assertAlmostEqual(std_vals[3] / self.known_std[3], 1.0, places=0)
         self.assertAlmostEqual(std_vals[4] / self.known_std[4], 1.0, places=1)
 
@@ -521,15 +527,17 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [pcal]
 pcal_dewhiten               = 1.0, 1.0
 ref_pcal_2_darm_act_sign    = -1.0
@@ -555,15 +563,17 @@ is_pro_spring = False
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [pcal]
 pcal_dewhiten               = 1.0, 1.0
 ref_pcal_2_darm_act_sign    = -1.0
@@ -658,15 +668,17 @@ is_pro_spring = False
 anti_aliasing_rate_string = 16k
 anti_aliasing_method = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [pcal]
 pcal_dewhiten               = 1.0, 1.0
 ref_pcal_2_darm_act_sign    = -1.0
@@ -723,15 +735,17 @@ is_pro_spring = False
 anti_aliasing_rate_string = 16k
 anti_aliasing_method = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [pcal]
 pcal_dewhiten               = 1.0, 1.0
 ref_pcal_2_darm_act_sign    = -1.0
@@ -833,11 +847,11 @@ anti_aliasing_method      = biquad
         for n in range(len(test[0][0])):
             self.assertAlmostEqual(test[0][0][n] / self.known_freq[n], 1.0)
             self.assertAlmostEqual(
-                np.abs(test[0][1][n])/np.abs(self.known_opt_resp[n]), 1.0)
+                np.abs(test[0][1][n])/np.abs(self.known_opt_resp[n]), 1.0, places=6)
             self.assertAlmostEqual(
                 np.abs(np.angle(test[0][1][n], deg=True) -
                        np.angle(self.known_opt_resp[n], deg=True)),
-                0.0)
+                0.0, places=6)
             self.assertAlmostEqual(test[0][2][n] / self.known_unc[n], 1.0)
 
 class TestSensingGPR(unittest.TestCase):
@@ -859,15 +873,17 @@ is_pro_spring = False
 anti_aliasing_rate_string = 16k
 anti_aliasing_method = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 [pcal]
 pcal_dewhiten               = 1.0, 1.0
 ref_pcal_2_darm_act_sign    = -1.0
@@ -1004,14 +1020,14 @@ uim_drive_align_bank    = ETMX_L1_DRIVEALIGN_L2L
 uim_drive_align_modules =
 uim_drive_align_gain    = 1.0
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 pum_driver_DC_trans_ApV = 2.6847e-4
@@ -1125,14 +1141,14 @@ uim_drive_align_bank    = ETMX_L1_DRIVEALIGN_L2L
 uim_drive_align_modules =
 uim_drive_align_gain    = 1.0
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 pum_driver_DC_trans_ApV = 2.6847e-4
@@ -1247,14 +1263,14 @@ uim_drive_align_bank    = ETMX_L1_DRIVEALIGN_L2L
 uim_drive_align_modules =
 uim_drive_align_gain    = 1.0
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 pum_driver_DC_trans_ApV = 2.6847e-4
@@ -1381,14 +1397,14 @@ uim_drive_align_bank    = ETMX_L1_DRIVEALIGN_L2L
 uim_drive_align_modules =
 uim_drive_align_gain    = 1.0
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 pum_driver_DC_trans_ApV = 2.6847e-4
@@ -1507,14 +1523,26 @@ uim_drive_align_bank    = ETMX_L1_DRIVEALIGN_L2L
 uim_drive_align_modules =
 uim_drive_align_gain    = 1.0
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation_UL = ON
+tst_front_end_driver_compensation_LL = ON
+tst_front_end_driver_compensation_UR = ON
+tst_front_end_driver_compensation_LR = ON
+pum_front_end_driver_compensation_UL = ON
+pum_front_end_driver_compensation_LL = ON
+pum_front_end_driver_compensation_UR = ON
+pum_front_end_driver_compensation_LR = ON
+uim_front_end_driver_compensation_UL = ON
+uim_front_end_driver_compensation_LL = ON
+uim_front_end_driver_compensation_UR = ON
+uim_front_end_driver_compensation_LR = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 pum_driver_DC_trans_ApV = 2.6847e-4
@@ -1596,14 +1624,26 @@ uim_drive_align_bank    = ETMX_L1_DRIVEALIGN_L2L
 uim_drive_align_modules =
 uim_drive_align_gain    = 1.0
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation_UL = ON
+tst_front_end_driver_compensation_LL = ON
+tst_front_end_driver_compensation_UR = ON
+tst_front_end_driver_compensation_LR = ON
+pum_front_end_driver_compensation_UL = ON
+pum_front_end_driver_compensation_LL = ON
+pum_front_end_driver_compensation_UR = ON
+pum_front_end_driver_compensation_LR = ON
+uim_front_end_driver_compensation_UL = ON
+uim_front_end_driver_compensation_LL = ON
+uim_front_end_driver_compensation_UR = ON
+uim_front_end_driver_compensation_LR = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 pum_driver_DC_trans_ApV = 2.6847e-4
@@ -1749,14 +1789,26 @@ uim_drive_align_bank    = ETMX_L1_DRIVEALIGN_L2L
 uim_drive_align_modules =
 uim_drive_align_gain    = 1.0
 suspension_file = test/H1susdata_O3.mat
-tst_driver_meas_Z_UL = 129.7e3
-tst_driver_meas_Z_LL = 90.74e3
-tst_driver_meas_Z_UR = 93.52e3
-tst_driver_meas_Z_LR = 131.5e3
-tst_driver_meas_P_UL = 3.213e3, 31.5e3
-tst_driver_meas_P_LL = 3.177e3, 26.7e3
-tst_driver_meas_P_UR = 3.279e3, 26.6e3
-tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_uncompensated_Z_UL = 129.7e3
+tst_driver_uncompensated_Z_LL = 90.74e3
+tst_driver_uncompensated_Z_UR = 93.52e3
+tst_driver_uncompensated_Z_LR = 131.5e3
+tst_driver_uncompensated_P_UL = 3.213e3, 31.5e3
+tst_driver_uncompensated_P_LL = 3.177e3, 26.7e3
+tst_driver_uncompensated_P_UR = 3.279e3, 26.6e3
+tst_driver_uncompensated_P_LR = 3.238e3, 31.6e3
+tst_front_end_driver_compensation_UL = ON
+tst_front_end_driver_compensation_LL = ON
+tst_front_end_driver_compensation_UR = ON
+tst_front_end_driver_compensation_LR = ON
+pum_front_end_driver_compensation_UL = ON
+pum_front_end_driver_compensation_LL = ON
+pum_front_end_driver_compensation_UR = ON
+pum_front_end_driver_compensation_LR = ON
+uim_front_end_driver_compensation_UL = ON
+uim_front_end_driver_compensation_LL = ON
+uim_front_end_driver_compensation_UR = ON
+uim_front_end_driver_compensation_LR = ON
 tst_driver_DC_gain_VpV_HV = 40
 tst_driver_DC_gain_VpV_LV = 1.881
 pum_driver_DC_trans_ApV = 2.6847e-4
