@@ -92,7 +92,8 @@ class TestOMCDCPDTransimpedenceAmplifierResponse(unittest.TestCase):
 [interferometer]
 [sensing]
 omc_path_names = A
-omc_meas_p_trans_amplifier = 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated = 13.7e3, 17.8e3
+omc_front_end_trans_amplifier_compensation = ON
 ''')
         test_response = C.omc_dcpd_transimpedence_amplifier_response(
             'A', self.frequencies)
@@ -132,7 +133,8 @@ class TestOMCDCPDWhiteningResponse(unittest.TestCase):
 [sensing]
 omc_path_names = A
 whitening_mode_names = test
-omc_meas_p_whitening_test = 11.346e3, 32.875e3, 32.875e3
+omc_meas_p_whitening_uncompensated_test = 11.346e3, 32.875e3, 32.875e3
+omc_front_end_whitening_compensation_test = ON
 ''')
         test_response = C.omc_dcpd_whitening_response(
             'A', self.frequencies)
@@ -178,11 +180,13 @@ class TestOMCAnalaogDCPDReadoutResponse(unittest.TestCase):
 [interferometer]
 [sensing]
 omc_path_names = A
-omc_meas_p_trans_amplifier = 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated = 13.7e3, 17.8e3
 whitening_mode_names = test
-omc_meas_p_whitening_test = 11.346e3, 32.875e3, 32.875e3
+omc_meas_p_whitening_uncompensated_test = 11.346e3, 32.875e3, 32.875e3
 super_high_frequency_poles_apparent_delay = 0
 analog_anti_aliasing_file = test/H1aa.mat
+omc_front_end_trans_amplifier_compensation = ON
+omc_front_end_whitening_compensation_test = ON
 ''')
         analog_dcpd_response = C.omc_analog_dcpd_readout_response('A',
             self.frequencies)
@@ -195,7 +199,7 @@ analog_anti_aliasing_file = test/H1aa.mat
                 np.angle(self.known_analog_response[n], deg=True))
 
 
-class TestOMCDigitalCompensationResponse(unittest.TestCase):
+class TestOMCDigitalFiltersResponse(unittest.TestCase):
 
     def setUp(self):
         self.frequencies = np.logspace(0, np.log10(5000.), 10)
@@ -215,25 +219,28 @@ class TestOMCDigitalCompensationResponse(unittest.TestCase):
         del self.frequencies
         del self.known_digital_response
 
-    def test_omc_digital_compensation_response(self):
+    def test_omc_digital_filters_response(self):
         C = pydarm.sensing.SensingModel('''
 [metadata]
 [interferometer]
 [sensing]
 omc_path_names = A
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A
-omc_compensation_filter_modules_in_use = 1,4,5,7
-omc_compensation_filter_gain = 1000
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A
+omc_filter_noncompensating_modules = 1,4,5,7
+omc_filter_gain = 1000
+whitening_mode_names = test
+omc_front_end_trans_amplifier_compensation = ON
+omc_front_end_whitening_compensation_test = ON
 ''')
-        digital_compensation_response = C.omc_digital_compensation_response('A',
+        digital_filters_response = C.omc_digital_filters_response('A',
             self.frequencies)
         for n in range(len(self.frequencies)):
             self.assertAlmostEqual(
-                np.abs(digital_compensation_response[n]),
+                np.abs(digital_filters_response[n]),
                 np.abs(self.known_digital_response[n]))
             self.assertAlmostEqual(
-                np.angle(digital_compensation_response[n], deg=True),
+                np.angle(digital_filters_response[n], deg=True),
                 np.angle(self.known_digital_response[n], deg=True))
 
 
@@ -274,11 +281,11 @@ class TestOmcPathResponse(unittest.TestCase):
 [interferometer]
 [sensing]
 omc_path_names = A
-omc_meas_z_trans_amplifier =
-omc_meas_p_trans_amplifier = 13.7e3, 17.8e3
+omc_meas_z_trans_amplifier_uncompensated =
+omc_meas_p_trans_amplifier_uncompensated = 13.7e3, 17.8e3
 whitening_mode_names = test
-omc_meas_z_whitening_test =
-omc_meas_p_whitening_test = 11.346e3, 32.875e3, 32.875e3
+omc_meas_z_whitening_uncompensated_test =
+omc_meas_p_whitening_uncompensated_test = 11.346e3, 32.875e3, 32.875e3
 super_high_frequency_poles_apparent_delay = 0
 analog_anti_aliasing_file = test/H1aa.mat
 anti_aliasing_rate_string = 16k
@@ -286,10 +293,12 @@ anti_aliasing_method      = biquad
 gain_ratio = 1
 balance_matrix = 1
 adc_gain = 1638.001638001638
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A
-omc_compensation_filter_modules_in_use = 4
-omc_compensation_filter_gain = 1
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A
+omc_filter_noncompensating_modules = 4
+omc_filter_gain = 1
+omc_front_end_trans_amplifier_compensation = ON
+omc_front_end_whitening_compensation_test = ON
 ''')
         omc_dcpd_response = C.omc_path_response('A', self.frequencies)
         for n in range(len(self.frequencies)):
@@ -347,17 +356,19 @@ omc_path_names = A, B
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 adc_gain = 1638.001638001638, 1638.001638001638
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A, OMC_DCPD_B
-omc_compensation_filter_modules_in_use = 4: 4
-omc_compensation_filter_gain = 1, 1
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A, OMC_DCPD_B
+omc_filter_noncompensating_modules = 4: 4
+omc_filter_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 ''')
         omc_dcpd_response = C.omc_combine_path_responses(self.frequencies)
         for n in range(len(self.frequencies)):
@@ -491,19 +502,21 @@ sensing_sign = 1
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1638.001638001638, 1638.001638001638
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A, OMC_DCPD_B
-omc_compensation_filter_modules_in_use = 4: 4
-omc_compensation_filter_gain = 1, 1
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A, OMC_DCPD_B
+omc_filter_noncompensating_modules = 4: 4
+omc_filter_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 ''')
         C_res = C.sensing_residual(self.frequencies)
         for n in range(len(self.frequencies)):
@@ -552,19 +565,21 @@ is_pro_spring = True
 anti_aliasing_rate_string = 16k
 anti_aliasing_method      = biquad
 analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
-omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+omc_meas_p_trans_amplifier_uncompensated   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
 whitening_mode_names = test, test
-omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+omc_meas_p_whitening_uncompensated_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
 super_high_frequency_poles_apparent_delay = 0, 0
 gain_ratio = 1, 1
 balance_matrix = 1, 1
 omc_path_names = A, B
 single_pole_approximation_delay_correction = -12e-6
 adc_gain = 1638.001638001638, 1638.001638001638
-omc_compensation_filter_file = test/H1OMC_1239468752.txt
-omc_compensation_filter_bank = OMC_DCPD_A, OMC_DCPD_B
-omc_compensation_filter_modules_in_use = 4: 4
-omc_compensation_filter_gain = 1, 1
+omc_filter_file = test/H1OMC_1239468752.txt
+omc_filter_bank = OMC_DCPD_A, OMC_DCPD_B
+omc_filter_noncompensating_modules = 4: 4
+omc_filter_gain = 1, 1
+omc_front_end_trans_amplifier_compensation = ON, ON
+omc_front_end_whitening_compensation_test = ON, ON
 ''')
         sensing_tf = C.compute_sensing(self.frequencies)
         for n in range(len(self.frequencies)):
